@@ -1,30 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
 """This module provides an utility function to retrieve the global hook_manager singleton
 in a Kedro's execution process.
 """
@@ -47,6 +20,8 @@ _hook_manager = None
 
 _PLUGIN_HOOKS = "kedro.hooks"  # entry-point to load hooks from for installed plugins
 
+logger = logging.getLogger(__name__)
+
 
 def _create_hook_manager() -> PluginManager:
     """Create a new PluginManager instance and register Kedro's hook specs."""
@@ -96,7 +71,7 @@ def _register_hooks_setuptools(
 
     """
     already_registered = hook_manager.get_plugins()
-    found = hook_manager.load_setuptools_entrypoints(_PLUGIN_HOOKS)
+    hook_manager.load_setuptools_entrypoints(_PLUGIN_HOOKS)
     disabled_plugins = set(disabled_plugins)
 
     # Get list of plugin/distinfo tuples for all setuptools registered plugins.
@@ -110,20 +85,19 @@ def _register_hooks_setuptools(
             # name and not `entry_point` name. Also, we log project names with
             # version for which hooks were registered.
             hook_manager.unregister(plugin=plugin)
-            found -= 1
             disabled_plugin_names.add(f"{dist.project_name}-{dist.version}")
         elif plugin not in already_registered:
             plugin_names.add(f"{dist.project_name}-{dist.version}")
 
     if disabled_plugin_names:
-        logging.info(
+        logger.info(
             "Hooks are disabled for plugin(s): %s",
             ", ".join(sorted(disabled_plugin_names)),
         )
 
     if plugin_names:
-        logging.info(
+        logger.info(
             "Registered hooks from %d installed plugin(s): %s",
-            found,
+            len(plugin_names),
             ", ".join(sorted(plugin_names)),
         )
