@@ -1,33 +1,6 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
 """``kedro.framework.project`` module provides utitlity to
 configure a Kedro project and access its settings."""
-# pylint: disable=redefined-outer-name,unused-argument
+# pylint: disable=redefined-outer-name,unused-argument,global-statement
 import importlib
 import operator
 from collections.abc import MutableMapping
@@ -54,8 +27,8 @@ def _get_default_class(class_import_path):
 class _IsSubclassValidator(Validator):
     """A validator to check if the supplied setting value is a subclass of the default class"""
 
-    def _validate_items(self, settings, env=None):
-        super()._validate_items(settings, env)
+    def validate(self, settings, *args, **kwargs):
+        super().validate(settings, *args, **kwargs)
 
         default_class = self.default(settings, self)
         for name in self.names:
@@ -196,26 +169,18 @@ class _ProjectPipelines(MutableMapping):
     __str__ = _load_data_wrapper(str)
 
 
+PACKAGE_NAME = None
+
 settings = _ProjectSettings()
 
-
 pipelines = _ProjectPipelines()
 
 
-def _validate_module(settings_module):
-    """Eagerly validate that the module is importable.
-    This ensures that the settings module is syntactically
-    correct so that any import errors are surfaced early.
-    """
-    importlib.import_module(settings_module)
-
-
 def configure_project(package_name: str):
     """Configure a Kedro project by populating its settings with values
     defined in user's settings.py and pipeline_registry.py.
     """
     settings_module = f"{package_name}.settings"
-    _validate_module(settings_module)
     settings.configure(settings_module)
 
     # set up all hooks so we can discover all pipelines
@@ -225,3 +190,21 @@ def configure_project(package_name: str):
 
     pipelines_module = f"{package_name}.pipeline_registry"
     pipelines.configure(pipelines_module)
+
+    # Once the project is successfully configured once, store PACKAGE_NAME as a
+    # global variable to make it easily accessible. This is used by validate_settings()
+    # below, and also by ParallelRunner on Windows, as package_name is required every
+    # time a new subprocess is spawned.
+    global PACKAGE_NAME
+    PACKAGE_NAME = package_name
+
+
+def validate_settings():
+    """Eagerly validate that the settings module is importable. This is desirable to
+    surface any syntax or import errors early. In particular, without eagerly importing
+    the settings module, dynaconf would silence any import error (e.g. missing
+    dependency, missing/mislabelled pipeline), and users would instead get a cryptic
+    error message ``Expected an instance of `ConfigLoader`, got `NoneType` instead``.
+    More info on the dynaconf issue: https://github.com/rochacbruno/dynaconf/issues/460
+    """
+    importlib.import_module(f"{PACKAGE_NAME}.settings")
