@@ -1,30 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
 """``DataCatalog`` stores instances of ``AbstractDataSet`` implementations to
 provide ``load`` and ``save`` capabilities from anywhere in the program. To
 use a ``DataCatalog``, you need to instantiate it with a dictionary of data
@@ -39,7 +12,6 @@ import warnings
 from collections import defaultdict
 from functools import partial
 from typing import Any, Callable, Dict, Iterable, List, Optional, Set, Type, Union
-from warnings import warn
 
 from kedro.io.core import (
     AbstractDataSet,
@@ -56,6 +28,7 @@ from kedro.versioning import Journal
 
 CATALOG_KEY = "catalog"
 CREDENTIALS_KEY = "credentials"
+WORDS_REGEX_PATTERN = re.compile(r"\W+")
 
 
 def _get_credentials(
@@ -120,22 +93,36 @@ def _sub_nonword_chars(data_set_name: str) -> str:
     Returns:
         The name used in `DataCatalog.datasets`.
     """
-    return re.sub(r"\W+", "__", data_set_name)
+    return re.sub(WORDS_REGEX_PATTERN, "__", data_set_name)
 
 
 class _FrozenDatasets:
     """Helper class to access underlying loaded datasets"""
 
-    def __init__(self, datasets):
-        # Non-word characters in dataset names are replaced with `__`
-        # for easy access to transcoded/prefixed datasets.
-        datasets = {_sub_nonword_chars(key): value for key, value in datasets.items()}
-        self.__dict__.update(**datasets)
+    def __init__(
+        self,
+        *datasets_collections: Union["_FrozenDatasets", Dict[str, AbstractDataSet]],
+    ):
+        """Return a _FrozenDatasets instance from some datasets collections.
+        Each collection could either be another _FrozenDatasets or a dictionary.
+        """
+        for collection in datasets_collections:
+            if isinstance(collection, _FrozenDatasets):
+                self.__dict__.update(collection.__dict__)
+            else:
+                # Non-word characters in dataset names are replaced with `__`
+                # for easy access to transcoded/prefixed datasets.
+                self.__dict__.update(
+                    {
+                        _sub_nonword_chars(dataset_name): dataset
+                        for dataset_name, dataset in collection.items()
+                    }
+                )
 
     # Don't allow users to add/change attributes on the fly
     def __setattr__(self, key, value):
         msg = "Operation not allowed! "
-        if key in self.__dict__.keys():
+        if key in self.__dict__:
             msg += "Please change datasets through configuration."
         else:
             msg += "Please use DataCatalog.add() instead."
@@ -198,6 +185,14 @@ class DataCatalog:
         self.datasets = _FrozenDatasets(self._data_sets)
         self.layers = layers
 
+        if transformers or default_transformers:
+            warnings.warn(
+                "The transformer API will be deprecated in Kedro 0.18.0."
+                "Please use Dataset Hooks to customise the load and save methods."
+                "For more information, please visit"
+                "https://kedro.readthedocs.io/en/stable/07_extend_kedro/02_hooks.html",
+                DeprecationWarning,
+            )
         self._transformers = {k: list(v) for k, v in (transformers or {}).items()}
         self._default_transformers = list(default_transformers or [])
         self._check_and_normalize_transformers()
@@ -218,9 +213,7 @@ class DataCatalog:
 
         if excess_transformers:
             raise DataSetNotFoundError(
-                "Unexpected transformers for missing data_sets {}".format(
-                    ", ".join(excess_transformers)
-                )
+                f"Unexpected transformers for missing data_sets {', '.join(excess_transformers)}"
             )
 
         for data_set_name in missing_transformers:
@@ -268,6 +261,8 @@ class DataCatalog:
         Raises:
             DataSetError: When the method fails to create any of the data
                 sets from their config.
+            DataSetNotFoundError: When `load_versions` refers to a dataset that doesn't
+                exist in the catalog.
 
         Example:
         ::
@@ -313,7 +308,7 @@ class DataCatalog:
 
         missing_keys = load_versions.keys() - catalog.keys()
         if missing_keys:
-            warn(
+            raise DataSetNotFoundError(
                 f"`load_versions` keys [{', '.join(sorted(missing_keys))}] "
                 f"are not found in the catalog."
             )
@@ -526,7 +521,7 @@ class DataCatalog:
                 )
         self._data_sets[data_set_name] = data_set
         self._transformers[data_set_name] = list(self._default_transformers)
-        self.datasets = _FrozenDatasets(self._data_sets)
+        self.datasets = _FrozenDatasets(self.datasets, {data_set_name: data_set})
 
     def add_all(
         self, data_sets: Dict[str, AbstractDataSet], replace: bool = False
@@ -618,15 +613,13 @@ class DataCatalog:
             "The transformer API will be deprecated in Kedro 0.18.0."
             "Please use Dataset Hooks to customise the load and save methods."
             "For more information, please visit"
-            "https://kedro.readthedocs.io/en/stable/07_extend_kedro/04_hooks.html",
+            "https://kedro.readthedocs.io/en/stable/07_extend_kedro/02_hooks.html",
             DeprecationWarning,
         )
 
         if not isinstance(transformer, AbstractTransformer):
             raise TypeError(
-                "Object of type {} is not an instance of AbstractTransformer".format(
-                    type(transformer)
-                )
+                f"Object of type {type(transformer)} is not an instance of AbstractTransformer"
             )
         if data_set_names is None:
             self._default_transformers.append(transformer)
@@ -671,7 +664,7 @@ class DataCatalog:
             return list(self._data_sets.keys())
 
         if not regex_search.strip():
-            logging.warning("The empty string will not match any data sets")
+            self._logger.warning("The empty string will not match any data sets")
             return []
 
         try:
