@@ -1,31 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 """``PartitionedDataSet`` loads and saves partitioned file-like data using the
 underlying dataset definition. It also uses `fsspec` for filesystem level operations.
 """
@@ -64,7 +36,33 @@ class PartitionedDataSet(AbstractDataSet):
     underlying dataset definition. For filesystem level operations it uses `fsspec`:
     https://github.com/intake/filesystem_spec.
 
-    Example:
+    Example adding a catalog entry with
+    `YAML API <https://kedro.readthedocs.io/en/stable/05_data/\
+        01_data_catalog.html#using-the-data-catalog-with-the-yaml-api>`_:
+
+    .. code-block:: yaml
+
+        >>> cv_results_partitioned: # example to save results to multiple partitions
+        >>>   type: PartitionedDataSet
+        >>>   dataset:
+        >>>     type: pandas.CSVDataSet
+        >>>     save_args:
+        >>>       index: False
+        >>>   path: data/04_cv/
+        >>>   filename_suffix: ".csv"
+        >>>
+        >>>   downloaded_data: # example with data available in multiple partitions
+        >>>     type: PartitionedDataSet
+        >>>     path: demo/01_raw/downloaded_station_data
+        >>>     dataset:
+        >>>       type: pandas.CSVDataSet
+        >>>       load_args:
+        >>>         sep: ','
+        >>>         index_col: 0
+        >>>     filename_suffix: '.csv'
+
+
+    Example using Python API:
     ::
 
         >>> import pandas as pd
@@ -105,6 +103,7 @@ class PartitionedDataSet(AbstractDataSet):
         credentials: Dict[str, Any] = None,
         load_args: Dict[str, Any] = None,
         fs_args: Dict[str, Any] = None,
+        overwrite: bool = False,
     ):
         """Creates a new instance of ``PartitionedDataSet``.
 
@@ -142,6 +141,7 @@ class PartitionedDataSet(AbstractDataSet):
                 the filesystem implementation.
             fs_args: Extra arguments to pass into underlying filesystem class constructor
                 (e.g. `{"project": "my-project"}` for ``GCSFileSystem``)
+            overwrite: If True, any existing partitions will be removed.
 
         Raises:
             DataSetError: If versioning is enabled for the underlying dataset.
@@ -153,6 +153,7 @@ class PartitionedDataSet(AbstractDataSet):
 
         self._path = path
         self._filename_suffix = filename_suffix
+        self._overwrite = overwrite
         self._protocol = infer_storage_options(self._path)["protocol"]
         self._partition_cache = Cache(maxsize=1)
 
@@ -160,10 +161,9 @@ class PartitionedDataSet(AbstractDataSet):
         self._dataset_type, self._dataset_config = parse_dataset_definition(dataset)
         if VERSION_KEY in self._dataset_config:
             raise DataSetError(
-                "`{}` does not support versioning of the underlying dataset. "
-                "Please remove `{}` flag from the dataset definition.".format(
-                    self.__class__.__name__, VERSIONED_FLAG_KEY
-                )
+                f"`{self.__class__.__name__}` does not support versioning of the "
+                f"underlying dataset. Please remove `{VERSIONED_FLAG_KEY}` flag from "
+                f"the dataset definition."
             )
 
         if credentials:
@@ -190,8 +190,8 @@ class PartitionedDataSet(AbstractDataSet):
         self._filepath_arg = filepath_arg
         if self._filepath_arg in self._dataset_config:
             warn(
-                "`{}` key must not be specified in the dataset definition as it "
-                "will be overwritten by partition path".format(self._filepath_arg)
+                f"`{self._filepath_arg}` key must not be specified in the dataset "
+                f"definition as it will be overwritten by partition path"
             )
 
         self._load_args = deepcopy(load_args) or {}
@@ -258,6 +258,9 @@ class PartitionedDataSet(AbstractDataSet):
         return partitions
 
     def _save(self, data: Dict[str, Any]) -> None:
+        if self._overwrite and self._filesystem.exists(self._normalized_path):
+            self._filesystem.rm(self._normalized_path, recursive=True)
+
         for partition_id, partition_data in sorted(data.items()):
             kwargs = deepcopy(self._dataset_config)
             partition = self._partition_to_path(partition_id)
@@ -422,10 +425,8 @@ class IncrementalDataSet(PartitionedDataSet):
 
         for key in {VERSION_KEY, VERSIONED_FLAG_KEY} & checkpoint_config.keys():
             raise DataSetError(
-                "`{}` does not support versioning of the checkpoint. "
-                "Please remove `{}` key from the checkpoint definition.".format(
-                    self.__class__.__name__, key
-                )
+                f"`{self.__class__.__name__}` does not support versioning of the "
+                f"checkpoint. Please remove `{key}` key from the checkpoint definition."
             )
 
         default_checkpoint_path = self._sep.join(
@@ -438,7 +439,9 @@ class IncrementalDataSet(PartitionedDataSet):
         if self._credentials:
             default_config[CREDENTIALS_KEY] = deepcopy(self._credentials)
 
-        if CREDENTIALS_KEY in default_config.keys() & checkpoint_config.keys():
+        if (  # pylint: disable=consider-iterating-dictionary
+            CREDENTIALS_KEY in default_config.keys() & checkpoint_config.keys()
+        ):
             self._logger.warning(
                 KEY_PROPAGATION_WARNING,
                 {"keys": CREDENTIALS_KEY, "target": "checkpoint"},
