@@ -8,7 +8,7 @@ from concurrent.futures import FIRST_COMPLETED, ThreadPoolExecutor, wait
 from itertools import chain
 from typing import Set
 
-from kedro.io import AbstractDataSet, DataCatalog, MemoryDataSet
+from kedro.io import DataCatalog, MemoryDataSet
 from kedro.pipeline import Pipeline
 from kedro.pipeline.node import Node
 from kedro.runner.runner import AbstractRunner, run_node
@@ -48,15 +48,15 @@ class ThreadRunner(AbstractRunner):
 
         self._max_workers = max_workers
 
-    def create_default_data_set(self, ds_name: str) -> AbstractDataSet:
-        """Factory method for creating the default data set for the runner.
+    def create_default_data_set(self, ds_name: str) -> MemoryDataSet:  # type: ignore
+        """Factory method for creating the default dataset for the runner.
 
         Args:
-            ds_name: Name of the missing data set
+            ds_name: Name of the missing dataset.
 
         Returns:
-            An instance of an implementation of AbstractDataSet to be used
-            for all unregistered data sets.
+            An instance of ``MemoryDataSet`` to be used for all
+            unregistered datasets.
 
         """
         return MemoryDataSet()
@@ -125,9 +125,8 @@ class ThreadRunner(AbstractRunner):
                         "Completed %d out of %d tasks", len(done_nodes), len(nodes)
                     )
 
-                    # decrement load counts and release any data sets we've finished
-                    # with this is particularly important for the shared datasets we
-                    # create above
+                    # Decrement load counts, and release any datasets we
+                    # have finished with.
                     for data_set in node.inputs:
                         load_counts[data_set] -= 1
                         if (
