@@ -27,7 +27,7 @@ class Journal:
         warnings.warn(
             "`Journal` is now deprecated and will be removed in Kedro 0.18.0."
             "For more information, please visit "
-            "https://github.com/quantumblacklabs/kedro/blob/main/RELEASE.md",
+            "https://github.com/kedro-org/kedro/blob/main/RELEASE.md",
             DeprecationWarning,
         )
 
